@@ -65,8 +65,8 @@ class App(object):
         routes = []
         for p in Path(app_dir).rglob('*.py'):
             if not p.stem.startswith('_'):  # 过滤_开头的py
-                route = str(p)[:-3]
-                func = importlib.import_module(route.replace('/', '.')).main
+                route = '/' + str(p)[:-3]
+                func = importlib.import_module(route.strip('/').replace('/', '.')).main
                 self.add_route(route, func, method='POST', **kwargs)
 
                 routes.append(route)
