@@ -36,7 +36,7 @@ def clitest(name: str):
 def run(app_file: str, app='fastapi', port=9955, nohup=0):
     """Support fastapi/streamlit/gradio/gui app."""
     if not Path(app_file).exists():
-        app_file = Path(get_module_path('../apps', __file__)) / app_file
+        app_file = Path(get_module_path(f'../apps_{app}', __file__)) / app_file
 
     if app in ('fastapi', 'gui', 'gradio'):
         cmd = f"python {app_file}"
